cd "F:\EEH _ 0316025\JV2015_EEH_Replication_Files\Regressions\Country Level"

*********************************
*********************************
* ANALYSIS AT THE COUNTRY LEVEL *
*********************************
*********************************

* This do-file: 
* (1) recreates the data set at the country level "jv2015_country.dta" used for Jedwab & Vollrath (2015, forthcoming in Explorations in Economic History).
* (2) recreates the main results at the country level.
* This do-file was prepared by Remi Jedwab (GWU). Please send him an email at jedwab@gwu.edu if you have any questions about the data or the do-file.

*****************************
* DATA AT THE COUNTRY LEVEL *
*****************************

***************
* INCOME DATA *
***************

* We rely on the new Maddison (2008) data set created by J. Bolt and J. L. van Zanden (2014).
* The data set is available at http://www.ggdc.net/maddison/maddison-project/data.htm. 
* We cleaned their data set and changed the country name, in order to be able to match the data with the other sources we are using.

* This is the clean data set for the period before 1950.
clear
import excel "maddison_new_2010_cleaned_pre_1950.xls", sheet("raw") firstrow clear
drop if country == ""
count
* We have 162 countries in the data set. 
keep country-y1949
label var country "Country name"
sort country
save maddison_pre_1950, replace

* This is the clean data set for the period after 1950.
clear
import excel "maddison_new_2010_post_1950.xls", sheet("raw") firstrow clear
drop if country == ""
count
* We have 162 countries in the data set. 
drop B
* We merge the two data sets to obtain the full per capita GDP series.
sort country
merge country using maddison_pre_1950
tab _m
tab country if _m == 2
drop if _m == 2
drop _m
order country continent area y1-y1949 y1950-y2010
destring y1-y2010, replace
replace y2010 = y2009 if y2010 == . 
replace y2010 = y2008 if y2010 == . 
replace y2010 = y2007 if y2010 == . 
replace y2010 = y2006 if y2010 == . 
replace y2010 = y2005 if y2010 == . 
reshape long y, i(country) j(year)
ren y pcgdp
gen lpcgdp = log(pcgdp)
replace country = trim(country)
label var pcgdp "Per capita GDP (1990 Int. GK$)"
label var lpcgdp "Log per capita GDP (1990 Int. GK$)"
sort country year
save maddison_new_2010, replace

*********************
* URBANIZATION DATA *
*********************

* The main source for the data is the "World Urbanization Prospects: 2014 Revision" (United Nations, 2014). 
* The data can be found here: http://esa.un.org/unpd/wup/
* We complemented the United Nations data with data from other sources (see the notes below Figure 1). 

* This is the excel file that we recreate using the United Nations data set + the other sources.
clear
import excel "urbanization.xls", sheet("Feuil1")firstrow clear
reshape long y, i(country) j(year)
ren y urbrate
* We merge the urbanization data set with the income data set. 
sort country year
merge country year using maddison_new_2010
tab _m
drop _m
label var urbrate "Urbanization rate (%)"
label var continent "Region (N = 6)"
save jv2015_country, replace

* We also obtain the total population of each country in 2010 from United Nations (2014).
use pop, clear
ren Country country
keep country pop2010
label var pop2010 "Total population (000s inhabitants) in 2010"
sort country
save pop_new, replace

* We also obtain the area of each country in 2010 from the World Development Indicators data set of the World Bank (2013).
use area, clear
ren Country country
replace country = "Bolivia (Plurinational State of)" if country == "Bolivia"
replace country = "Bosnia and Herzegovina" if country == "Bosnia"
replace country = "Cabo Verde" if country == "Cape Verde"
replace country = "China, Hong Kong SAR" if country == "Hong Kong SAR, China"
replace country = "Comoros" if country == "Comoro Islands"
replace country = "Congo" if country == "Congo, Rep."
replace country = "Cte d'Ivoire" if country == "Cote d'Ivoire"
replace country = "Dem. People's Republic of Korea" if country == "Korea, Dem. Rep."
replace country = "Egypt" if country == "Egypt, Arab Rep."
replace country = "Gambia" if country == "Gambia, The"
replace country = "Guinea-Bissau" if country == "Guinea Bissau"
replace country = "Iran (Islamic Republic of)" if country == "Iran, Islamic Rep."
replace country = "Kyrgyzstan" if country == "Kyrgyz Republic"
replace country = "Lao People's Democratic Republic" if country == "Lao PDR"
replace country = "Republic of Korea" if country == "Korea, Rep."
replace country = "Republic of Moldova" if country == "Moldova"
replace country = "Sao Tome and Principe" if country == "Sao Tom & Principe"
replace country = "Slovakia" if country == "Slovak Republic"
replace country = "TFYR Macedonia" if country == "Macedonia, FYR"
replace country = "Trinidad and Tobago" if country == "T. & Tobago"
replace country = "United Republic of Tanzania" if country == "Tanzania"
replace country = "United States of America" if country == "United States"
replace country = "Venezuela (Bolivarian Republic of)" if country == "Venezuela, RB"
replace country = "Viet Nam" if country == "Vietnam"
replace country = "Yemen" if country == "Yemen, Rep."
replace country = "Democratic Republic of the Congo" if country == "Congo, Dem. Rep."
sort country
save area_new, replace

* We add total population and country area to the main data set.
use jv2015_country, clear
sort country
merge country using pop_new
tab _m
tab country if _m == 1
* ok
drop if _m == 2
drop _m
label var area "Area (N = 7)"
label var year "Year"
save jv2015_country, replace

************************
* ADDITIONAL VARIABLES *
************************

*** Country area ***

import excel "aera_new.xls", sheet("Sheet1") firstrow clear
sort country
save area_sqkm, replace

use jv2015_country, clear
sort country
merge country using area_sqkm
tab _m
drop if _m == 2
drop _m
label var area_sqkm "Country area (sq km)"
save jv2015_country, replace

*** Urban definition ***

* The main source for the data is the "World Urbanization Prospects: 2014 Revision" (United Nations, 2014). 
* The data can be found here: http://esa.un.org/unpd/wup/

clear
import excel "urban_definition.xls", sheet("Sheet1") firstrow clear
sort country
save urban_definition, replace

use jv2015_country, clear
sort country
merge country using urban_definition
tab _m
drop if _m == 2
drop _m
drop Condition_comment
label var Admin "Urban definition: Administrative"
label var Threshold "Urban definition: Based on a threshold"
label var Condition "Urban definition: Based on another condition"
label var Admin_or_threshold "Urban definition: Administrative or based on a threshold"
label var Threshold_level "Urban definition: Threshold used"
save jv2015_country, replace

*** Education ***

* The data come from Barro and Lee (2013). 
* The link to the original data set is http://www.barrolee.com/. 

use "BL2013_MF2599_v2.0.dta", clear
* For individuals aged 25 years or older.
keep if year == 1950 | year == 1960 | year == 1970 | year == 1980 | year == 1990 | year == 2000 | year == 2010
drop pop 
replace country = "Bolivia (Plurinational State of)" if country == "Bolivia"
replace country = "China, Hong Kong SAR" if country == "China, Hong Kong Special Administrative Region"
replace country = "China, Macao SAR" if country == "China, Macao Special Administrative Region"
replace country = "Cte d'Ivoire" if country == "Cote dIvoire"
replace country = "Dominican Republic" if country == "Dominican Rep."
replace country = "Libya" if country == "Libyan Arab Jamahiriya"
replace country = "United States of America" if country == "USA"
replace country = "Venezuela (Bolivarian Republic of)" if country == "Venezuela"
sort country year
save education25, replace

*** Industrial and service employment ***

* We recreate the data using the World Development Indicators data set of the World Bank (2014).
clear
import excel "induserv.xls", sheet("Data") firstrow clear
replace y1970 = y1971 if y1970 == .
replace y1970 = y1972 if y1970 == .
replace y1970 = y1973 if y1970 == .
replace y1970 = y1974 if y1970 == .
replace y1970 = y1975 if y1970 == .
replace y1980 = y1979 if y1980 == .
replace y1980 = y1981 if y1980 == .
replace y1980 = y1978 if y1980 == .
replace y1980 = y1982 if y1980 == .
replace y1980 = y1977 if y1980 == .
replace y1980 = y1983 if y1980 == .
replace y1980 = y1976 if y1980 == .
replace y1980 = y1984 if y1980 == .
replace y1980 = y1975 if y1980 == .
replace y1980 = y1985 if y1980 == .
replace y1990 = y1989 if y1990 == .
replace y1990 = y1991 if y1990 == .
replace y1990 = y1988 if y1990 == .
replace y1990 = y1992 if y1990 == .
replace y1990 = y1987 if y1990 == .
replace y1990 = y1993 if y1990 == .
replace y1990 = y1986 if y1990 == .
replace y1990 = y1994 if y1990 == .
replace y1990 = y1985 if y1990 == .
replace y1990 = y1995 if y1990 == .
replace y2000 = y1999 if y2000 == .
replace y2000 = y2001 if y2000 == .
replace y2000 = y1998 if y2000 == .
replace y2000 = y2002 if y2000 == .
replace y2000 = y1997 if y2000 == .
replace y2000 = y2003 if y2000 == .
replace y2000 = y1996 if y2000 == .
replace y2000 = y2004 if y2000 == .
replace y2000 = y1995 if y2000 == .
replace y2000 = y2005 if y2000 == .
replace y2010 = y2009 if y2010 == .
replace y2010 = y2011 if y2010 == .
replace y2010 = y2008 if y2010 == .
replace y2010 = y2012 if y2010 == .
replace y2010 = y2007 if y2010 == .
replace y2010 = y2013 if y2010 == .
replace y2010 = y2006 if y2010 == .
replace y2010 = y2014 if y2010 == .
replace y2010 = y2005 if y2010 == .
reshape long y, i(country series) j(year)
sort country year series
keep if series == "agr"
gen nonag = 100 - y
keep if year == 1950 | year == 1960 | year == 1970 | year == 1980 | year == 1990 | year == 2000 | year == 2010
keep country year nonag
replace country = "Bolivia (Plurinational State of)" if country == "Bolivia"
replace country = "Bosnia and Herzegovina" if country == "Bosnia"
replace country = "Cabo Verde" if country == "Cape Verde"
replace country = "China, Hong Kong SAR" if country == "Hong Kong SAR, China"
replace country = "Comoros" if country == "Comoro Islands"
replace country = "Congo" if country == "Congo, Rep."
replace country = "Cte d'Ivoire" if country == "Cote d'Ivoire"
replace country = "Dem. People's Republic of Korea" if country == "Korea, Dem. Rep."
replace country = "Egypt" if country == "Egypt, Arab Rep."
replace country = "Gambia" if country == "Gambia, The"
replace country = "Guinea-Bissau" if country == "Guinea Bissau"
replace country = "Iran (Islamic Republic of)" if country == "Iran, Islamic Rep."
replace country = "Kyrgyzstan" if country == "Kyrgyz Republic"
replace country = "Lao People's Democratic Republic" if country == "Lao PDR"
replace country = "Republic of Korea" if country == "Korea, Rep."
replace country = "Republic of Moldova" if country == "Moldova"
replace country = "Sao Tome and Principe" if country == "Sao Tom & Principe"
replace country = "Slovakia" if country == "Slovak Republic"
replace country = "TFYR Macedonia" if country == "Macedonia, FYR"
replace country = "Trinidad and Tobago" if country == "T. & Tobago"
replace country = "United Republic of Tanzania" if country == "Tanzania"
replace country = "United States of America" if country == "United States"
replace country = "Venezuela (Bolivarian Republic of)" if country == "Venezuela, RB"
replace country = "Viet Nam" if country == "Vietnam"
replace country = "Yemen" if country == "Yemen, Rep."
replace country = "Democratic Republic of the Congo" if country == "Congo, Dem. Rep."
replace country = "China, Macao SAR" if country == "Macao SAR, China"
sort country year
save induserv, replace

use jv2015_country, clear
sort country year
merge country year using education25
tab _m
tab country if _m == 2
* ok
drop if _m == 2
drop _m
sort country year
merge country year using induserv
tab _m
tab country if _m == 2
* ok
drop if _m == 2
drop _m
sort country year
label var nonag "Employment share of industry and services (%)"
save jv2015_country, replace
* This is the main data set that we use in our analysis. 

*************************************
* MAIN RESULTS AT THE COUNTRY LEVEL *
*************************************

use jv2015_country, clear
* We only keep the country-year observations for which we have the data on both urbanization and income.
keep if urbrate !=. & lpcgdp !=.
tab year
* These are the main years of our analysis. 
keep if year == 1500 | year == 1700 | year == 1800 | year == 1850 | year == 1870 | year == 1913 | year == 1950 | year == 1960 | year == 1970 | year == 1980 | year == 1990 | year == 2000 | year == 2010

************
* FIGURE 1 *
************

twoway (scatter urbrate lpcgdp) (lfit urbrate lpcgdp), ytitle(Urbanization Rate (%)) xtitle(Log Per Capita GDP (PPP, Constant 1990$))  xlabel(5(1)11) legend(off)
* We manually edit the figure using graph editor before exporting it. 
graph export figure1.png, replace width(2620) height(1908)
reg urbrate lpcgdp, robust

************
* FIGURE 2 *
************

twoway (scatter urbrate lpcgdp if year == 1500)(scatter urbrate lpcgdp if year == 1950)(scatter urbrate lpcgdp if year == 2010)(lfit urbrate lpcgdp if year == 1500)(lfit urbrate lpcgdp if year == 1950)(lfit urbrate lpcgdp if year == 2010), ytitle(Urbanization Rate (%)) xtitle(Log Per Capita GDP (PPP, Constant 1990$)) legend(order(1 "Obs. 1500" 2 "1950" 3 "2010" 4 "Linear Fit 1500" 5 "1950" 6 "2010") rows(2))
* We manually edit the figure using graph editor before exporting it. 
graph export figure2.png, replace width(2620) height(1908)
reg urbrate lpcgdp if year == 1500 | year == 1950 | year == 2010

************
* FIGURE 3 *
************

* We obtain the coefficient and the constant for each year.
reg urbrate lpcgdp if year == 1500, robust 
outreg2 lpcgdp using coeffs_figure3.xls, se bdec(2) adjr2 noni nolabel bracket title(Effect, "") nonotes replace
reg urbrate lpcgdp if year == 1700, robust 
outreg2 lpcgdp using coeffs_figure3.xls, se bdec(2) adjr2 noni nolabel bracket title(Effect, "") nonotes append
reg urbrate lpcgdp if year == 1800, robust 
outreg2 lpcgdp using coeffs_figure3.xls, se bdec(2) adjr2 noni nolabel bracket title(Effect, "") nonotes append
reg urbrate lpcgdp if year == 1850, robust 
outreg2 lpcgdp using coeffs_figure3.xls, se bdec(2) adjr2 noni nolabel bracket title(Effect, "") nonotes append
reg urbrate lpcgdp if year == 1870, robust 
outreg2 lpcgdp using coeffs_figure3.xls, se bdec(2) adjr2 noni nolabel bracket title(Effect, "") nonotes append
reg urbrate lpcgdp if year == 1913, robust 
outreg2 lpcgdp using coeffs_figure3.xls, se bdec(2) adjr2 noni nolabel bracket title(Effect, "") nonotes append
reg urbrate lpcgdp if year == 1950, robust 
outreg2 lpcgdp using coeffs_figure3.xls, se bdec(2) adjr2 noni nolabel bracket title(Effect, "") nonotes append
reg urbrate lpcgdp if year == 1960, robust 
outreg2 lpcgdp using coeffs_figure3.xls, se bdec(2) adjr2 noni nolabel bracket title(Effect, "") nonotes append
reg urbrate lpcgdp if year == 1970, robust 
outreg2 lpcgdp using coeffs_figure3.xls, se bdec(2) adjr2 noni nolabel bracket title(Effect, "") nonotes append
reg urbrate lpcgdp if year == 1980, robust 
outreg2 lpcgdp using coeffs_figure3.xls, se bdec(2) adjr2 noni nolabel bracket title(Effect, "") nonotes append
reg urbrate lpcgdp if year == 1990, robust 
outreg2 lpcgdp using coeffs_figure3.xls, se bdec(2) adjr2 noni nolabel bracket title(Effect, "") nonotes append
reg urbrate lpcgdp if year == 2000, robust 
outreg2 lpcgdp using coeffs_figure3.xls, se bdec(2) adjr2 noni nolabel bracket title(Effect, "") nonotes append
reg urbrate lpcgdp if year == 2010, robust 
outreg2 lpcgdp using coeffs_figure3.xls, se bdec(2) adjr2 noni nolabel bracket title(Effect, "") nonotes append
* We export all the coefficients in "coeffs_figure3.xls".
* We then create a new excel file "figure_3_coeffs.xls" which we format in order to use to produce figure 3.

* We import the coefficients
clear 
import excel "figure_3_coeffs.xls", sheet("Feuil1") firstrow clear
twoway (connected coeff_constant year, mcolor(black) msize(medium) msymbol(circle) lcolor(black) lwidth(medthick) lpattern(solid)) (connected constant year, yaxis(2)), ytitle(Coefficient of Log Per Capita GDP) ytitle(, size(medium)) graphregion(fcolor(white)lcolor(white) ifcolor(white) ilcolor(white))
* We manually edit the figure using graph editor before exporting it. 
graph export figure3.png, replace width(2620) height(1908)

************
* FIGURE 4 *
************

* In the file "figure_3_coeffs.xls", we also estimate the predicted urbanization rate at different levels of economic development. 
* We plot these predicted urbanization rates in figure 4.
clear 
import excel "figure_3_coeffs.xls", sheet("Feuil1") firstrow clear
twoway (connected urbanrate_ln6 year) (connected urbanrate_ln7 year) (connected urbanrate_ln8 year) (connected urbanrate_ln9 year), ytitle(Predicted Urbanization Rate (%)) legend(order(1 "LPCGDP = 6" 2 "LPCGDP = 7" 3 "LPCGDP = 8" 4 "LPCGDP = 9") rows(1))
* We manually edit the figure using graph editor before exporting it. 
graph export figure4.png, replace width(2620) height(1908)

************************
* WEB APPENDIX FIGURES *
************************

**************
* FIGURE A.1 *
**************

use jv2015_country, clear
keep if urbrate !=. & lpcgdp !=.
keep if year == 1500 | year == 1800 | year == 1870 | year == 1950
twoway (lfit urbrate lpcgdp if year == 1500)(lfit urbrate lpcgdp if year == 1700)(lfit urbrate lpcgdp if year == 1800)(lfit urbrate lpcgdp if year == 1850)(lfit urbrate lpcgdp if year == 1870)(lfit urbrate lpcgdp if year == 1913)(lfit urbrate lpcgdp if year == 1950), ytitle(Urbanization Rate (%)) xtitle(Log Per Capita GDP (PPP, Constant 1990$)) legend(order(1 "1500" 2 "1700" 3 "1800" 4 "1850" 5 "1870" 6 "1910" 7 "1950") rows(1))
* We manually edit the graph using graph editor.
graph export figureA1.png, replace width(2620) height(1908)

**************
* FIGURE A.2 *
**************

use jv2015_country, clear
keep if urbrate !=. & lpcgdp !=.
keep if year == 1950 | year == 1970 | year == 1990 | year == 2010
twoway (lfit urbrate lpcgdp if year == 1950)(lfit urbrate lpcgdp if year == 1970)(lfit urbrate lpcgdp if year == 1990)(lfit urbrate lpcgdp if year == 2010), ytitle(Urbanization Rate (%)) xtitle(Log Per Capita Income) legend(order(1 "1950" 2 "1970" 3 "1990" 4 "2010"))
* We manually edit the graph using graph editor.
graph export figureA2.png, replace width(2620) height(1908)

**************
* FIGURE A.3 *
**************

* We use the averages for the world in the Maddison and United Nations data sets to compute the ratio for the world. 
* We add the ratio to the excel file "robustness_summary.xls".
clear
import excel "robustness_summary.xls", sheet("noconstant") firstrow clear
twoway (connected coeff_noconstant year, mcolor(black) msize(medium) msymbol(circle) lcolor(black) lwidth(medthick) lpattern(solid)) (line world_ratio year, lcolor(black) lwidth(medthick) lpattern(dash)), ytitle(Coefficient of Log Per Capita GDP) ytitle(, size(medium)) xtitle(.) xtitle(, size(zero) color(white)) xlabel(1(1)13) legend(order(1 "Baseline" 2 "Ratio for the World") rows(1) span) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
* We manually edit the graph using graph editor.
graph export figureA3.png, replace width(2620) height(1908)

**************
* FIGURE A.4 *
**************

import excel "figure_3_coeffs.xls", sheet("Feuil1") firstrow clear
twoway (connected coeff_constant year, mcolor(black) msize(medium) msymbol(circle) lcolor(black) lwidth(medthick) lpattern(solid))(line coeff_constant_upper year, lcolor(gs6) lwidth(medthick) lpattern(dash))(line coeff_constant_lower year, lcolor(gs6) lwidth(medthick) lpattern(dash)) (connected constant year, yaxis(2)) (line constant_lower year, yaxis(2) lcolor(gs10) lwidth(medthick) lpattern(dash))(line constant_upper year, yaxis(2) lcolor(gs10) lwidth(medthick) lpattern(dash)), ytitle(Coefficient of Log Per Capita GDP) ytitle(, size(medium)) graphregion(fcolor(white)lcolor(white) ifcolor(white) ilcolor(white))
* We manually edit the graph using graph editor.
graph export figureA4.png, replace width(2620) height(1908)

**************
* FIGURE A.5 *
**************

set matsize 800
use jv2015_country, clear
keep if urbrate != . & lpcgdp != . 
keep if year == 1500 | year == 1700 | year == 1800 | year == 1850 | year == 1870 | year == 1913 | year == 1950 | year == 1960 | year == 1970 | year == 1980 | year == 1990 | year == 2000 | year == 2010
* We run the panel regression, and then extract the coefficients.
xi: areg urbrate i.year|lpcgdp i.year, robust absorb(country) cluster(country)
outreg2 ** using coeffs_figureA5.xls, se bdec(2) adjr2 noni nolabel bracket title(Effect, "") nonotes replace
* We add the coefficients to the excel file "robustness_summary.xls".

clear
import excel "robustness_summary.xls", sheet("constant") firstrow clear
twoway (connected coeff_panel year, mcolor(black) msize(medium) msymbol(circle) lcolor(black) lwidth(medthick) lpattern(solid)) (line noconstant_panel year, yaxis(2) lcolor(gs6) lwidth(medthick) lpattern(solid)), ytitle(Coefficient of Log Per Capita GDP) ytitle(, size(medium)) xtitle(.) xtitle(, size(zero) color(white)) xline(6, lwidth(medthick) lpattern(dash) lcolor(gs10)) xlabel(1(1)13) legend(order(1 "Coefficient of Log Per Capita GDP" 2 "Constant") rows(1) span) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
* We manually edit the graph using graph editor.
graph export figureA5.png, replace width(2620) height(1908)

**************
* FIGURE A.6 *
**************

use jv2015_country, clear
keep if urbrate != . & lpcgdp != . 
gen developed = log(12348.2387368355)
sum developed
* 9.42
* Slovakia became a developed country in 2009 according to the IMF (2009).
* We thus use Slovakia as the threshold.
keep if lpcgdp < developed
* We first obtain the coefficients.
reg urbrate lpcgdp if year == 1500, robust
outreg2 lpcgdp using figureA6.xls, ci se bdec(2) adjr2 noni nolabel noaster bracket title(Effect, "") nonotes replace
foreach X of numlist 1700 1800 1850 1870 1913 1950 1960 1970 1980 1990 2000 2010 {
reg urbrate lpcgdp if year == `X', robust
outreg2 lpcgdp using figureA6.xls, ci se bdec(2) adjr2 noni nolabel noaster bracket title(Effect, "") nonotes append
}
* We add the coefficients to the excel file "robustness_summary.xls".

clear
import excel "robustness_summary.xls", sheet("constant") firstrow clear
twoway (connected coeff_developing year, mcolor(black) msize(medium) msymbol(circle) lcolor(black) lwidth(medthick) lpattern(solid)) (line noconstant_developing year, yaxis(2) lcolor(gs6) lwidth(medthick) lpattern(solid)), ytitle(Coefficient of Log Per Capita GDP) ytitle(, size(medium)) xtitle(.) xtitle(, size(zero) color(white)) xline(6, lwidth(medthick) lpattern(dash) lcolor(gs10)) xlabel(1(1)13) legend(order(1 "Coefficient of Log Per Capita GDP" 2 "Constant") rows(1) span) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
* We manually edit the graph using graph editor.
graph export figureA6.png, replace width(2620) height(1908)

**************
* FIGURE A.7 *
**************

use jv2015_country, clear
keep if urbrate != . & lpcgdp != . 
gen developed = log(12348.2387368355)
sum developed
keep if lpcgdp < 8.50
* 8.5 = Botswana and below. 
* We first obtain the coefficients.
reg urbrate lpcgdp if year == 1500, robust
outreg2 lpcgdp using figureA6.xls, ci se bdec(2) adjr2 noni nolabel noaster bracket title(Effect, "") nonotes replace
foreach X of numlist 1700 1800 1850 1870 1913 1950 1960 1970 1980 1990 2000 2010 {
reg urbrate lpcgdp if year == `X', robust
outreg2 lpcgdp using figureA6.xls, ci se bdec(2) adjr2 noni nolabel noaster bracket title(Effect, "") nonotes append
}
* We add the coefficients to the excel file "robustness_summary.xls".

clear
import excel "robustness_summary.xls", sheet("constant") firstrow clear
twoway (connected coeff_poor year, mcolor(black) msize(medium) msymbol(circle) lcolor(black) lwidth(medthick) lpattern(solid)) (line noconstant_poor year, yaxis(2) lcolor(gs6) lwidth(medthick) lpattern(solid)), ytitle(Coefficient of Log Per Capita GDP) ytitle(, size(medium)) xtitle(.) xtitle(, size(zero) color(white)) xline(6, lwidth(medthick) lpattern(dash) lcolor(gs10)) xlabel(1(1)13) legend(order(1 "Coefficient of Log Per Capita GDP" 2 "Constant") rows(1) span) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
* We manually edit the graph using graph editor.
graph export figureA7.png, replace width(2620) height(1908)

**************
* FIGURE A.8 *
**************

use jv2015_country, clear
keep if urbrate != . & lpcgdp != .
twoway (kdensity Threshold_level if year == 2010)
* We manually edit the graph using graph editor.
graph export figureA8.png, replace width(2620) height(1908)

**************
* FIGURE A.9 *
**************

use jv2015_country, clear
keep if urbrate != . & lpcgdp != . 
* We create a few more additional variables. 
gen threshold_yn = (Threshold_level != .)
gen threshold_num = 0
replace threshold_num = Threshold_level if Threshold_level != .
* We obtain the coefficients when controlling for the urban definition.
reg urbrate lpcgdp threshold_yn threshold_num if year == 1500, robust
outreg2 lpcgdp using figureA9.xls, ci se bdec(2) adjr2 noni nolabel noaster bracket title(Effect, "") nonotes replace
foreach X of numlist 1700 1800 1850 1870 1913 1950 1960 1970 1980 1990 2000 2010 {
reg urbrate lpcgdp threshold_yn threshold_num if year == `X', robust
outreg2 lpcgdp using figureA9.xls, ci se bdec(2) adjr2 noni nolabel noaster bracket title(Effect, "") nonotes append
}
* We add the coefficients to the excel file "robustness_summary.xls".

clear
import excel "robustness_summary.xls", sheet("constant") firstrow clear
twoway (connected coeff_ctrldefinition year, mcolor(black) msize(medium) msymbol(circle) lcolor(black) lwidth(medthick) lpattern(solid)) (line noconstant_ctrldefinition year, yaxis(2) lcolor(gs6) lwidth(medthick) lpattern(solid)), ytitle(Coefficient of Log Per Capita GDP) ytitle(, size(medium)) xtitle(.) xtitle(, size(zero) color(white)) xline(6, lwidth(medthick) lpattern(dash) lcolor(gs10)) xlabel(1(1)13) legend(order(1 "Coefficient of Log Per Capita GDP" 2 "Constant") rows(1) span) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
* We manually edit the graph using graph editor.
graph export figureA9.png, replace width(2620) height(1908)

***************
* FIGURE A.10 *
***************

use jv2015_country, clear
keep if urbrate != . & lpcgdp != .
gen threshold_yn = (Threshold_level != .)
gen threshold_num = 0
replace threshold_num = Threshold_level if Threshold_level != .
drop if threshold_yn == 0
sum threshold_num if year == 2010, d
* we restrict the sample. 
drop if threshold_num <= 1000 | threshold_num >= 10000
* We obtain the coefficients when controlling for the urban definition.
reg urbrate lpcgdp if year == 1500, robust
outreg2 lpcgdp using figureA10.xls, ci se bdec(2) adjr2 noni nolabel noaster bracket title(Effect, "") nonotes replace
foreach X of numlist 1700 1800 1850 1870 1913 1950 1960 1970 1980 1990 2000 2010 {
reg urbrate lpcgdp if year == `X', robust
outreg2 lpcgdp using figureA10.xls, ci se bdec(2) adjr2 noni nolabel noaster bracket title(Effect, "") nonotes append
}
* We add the coefficients to the excel file "robustness_summary.xls".

clear
import excel "robustness_summary.xls", sheet("constant") firstrow clear
twoway (connected coeff_dropthreshold year, mcolor(black) msize(medium) msymbol(circle) lcolor(black) lwidth(medthick) lpattern(solid)) (line noconstant_dropthreshold year, yaxis(2) lcolor(gs6) lwidth(medthick) lpattern(solid)), ytitle(Coefficient of Log Per Capita GDP) ytitle(, size(medium)) xtitle(.) xtitle(, size(zero) color(white)) xline(6, lwidth(medthick) lpattern(dash) lcolor(gs10)) xlabel(1(1)13) legend(order(1 "Coefficient of Log Per Capita GDP" 2 "Constant") rows(1) span) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
* We manually edit the graph using graph editor.
graph export figureA10.png, replace width(2620) height(1908)

***************
* FIGURE A.11 *
***************

use jv2015_country, clear
* We drop Sub-Saharan Africa.
drop if area == "Africa"
reg urbrate lpcgdp if year == 1500, robust
outreg2 lpcgdp using figureA11.xls, ci se bdec(2) adjr2 noni nolabel noaster bracket title(Effect, "") nonotes replace
foreach X of numlist 1700 1800 1850 1870 1913 1950 1960 1970 1980 1990 2000 2010 {
reg urbrate lpcgdp if year == `X', robust
outreg2 lpcgdp using figureA11.xls, ci se bdec(2) adjr2 noni nolabel noaster bracket title(Effect, "") nonotes append
}
* We add the coefficients to the excel file "robustness_summary.xls".

clear
import excel "robustness_summary.xls", sheet("constant") firstrow clear
twoway (connected coeff_dropssa year, mcolor(black) msize(medium) msymbol(circle) lcolor(black) lwidth(medthick) lpattern(solid)) (line noconstant_dropssa year, yaxis(2) lcolor(gs6) lwidth(medthick) lpattern(solid)), ytitle(Coefficient of Log Per Capita GDP) ytitle(, size(medium)) xtitle(.) xtitle(, size(zero) color(white)) xline(6, lwidth(medthick) lpattern(dash) lcolor(gs10)) xlabel(1(1)13) legend(order(1 "Coefficient of Log Per Capita GDP" 2 "Constant") rows(1) span) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
* We manually edit the graph using graph editor.
graph export figureA11.png, replace width(2620) height(1908)

***************
* FIGURE A.12 *
***************

use jv2015_country, clear
tab area
* Africa 
* Asia 
* Europe
* MENA 
* North America
* Oceania 
* South America 
xi: reg urbrate lpcgdp i.area if year == 1500, robust nocons
areg urbrate lpcgdp if year == 1500, robust absorb(area)
outreg2 lpcgdp using graph2.xls, ci se bdec(2) adjr2 noni nolabel noaster bracket title(Effect, "") nonotes replace
foreach X of numlist 1700 1800 1850 1870 1913 1950 1960 1970 1980 1990 2000 2010 {
areg urbrate lpcgdp if year == `X', robust absorb(area)
outreg2 lpcgdp using graph2.xls, ci se bdec(2) adjr2 noni nolabel noaster bracket title(Effect, "") nonotes append
}
* We add the coefficients to the excel file "robustness_summary.xls".

clear
import excel "robustness_summary.xls", sheet("constant") firstrow clear
twoway (connected coeff_continentFE year, mcolor(black) msize(medium) msymbol(circle) lcolor(black) lwidth(medthick) lpattern(solid)) (line noconstant_continentFE year, yaxis(2) lcolor(gs6) lwidth(medthick) lpattern(solid)), ytitle(Coefficient of Log Per Capita GDP) ytitle(, size(medium)) xtitle(.) xtitle(, size(zero) color(white)) xline(6, lwidth(medthick) lpattern(dash) lcolor(gs10)) xlabel(1(1)13) legend(order(1 "Coefficient of Log Per Capita GDP" 2 "Constant") rows(1) span) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
* We manually edit the graph using graph editor.
graph export figureA12.png, replace width(2620) height(1908)

***************
* FIGURE A.13 *
***************

use jv2015_country, clear
keep if urbrate != . & lpcgdp != .
gen ratio10 = urbrate/lpcgdp if year == 2010
sum ratio10, d
gen outlier = (ratio <= 3.575974 | ratio >= 8.205821) if year == 2010
bysort country: egen outlier_yn = max(outlier)
drop if outlier_yn == 1
reg urbrate lpcgdp if year == 1500, robust
outreg2 lpcgdp using figureA13.xls, ci se bdec(2) adjr2 noni nolabel noaster bracket title(Effect, "") nonotes replace
foreach X of numlist 1700 1800 1850 1870 1913 1950 1960 1970 1980 1990 2000 2010 {
reg urbrate lpcgdp if year == `X', robust
outreg2 lpcgdp using figureA13.xls, ci se bdec(2) adjr2 noni nolabel noaster bracket title(Effect, "") nonotes append
}
* We add the coefficients to the excel file "robustness_summary.xls".

clear
import excel "robustness_summary.xls", sheet("constant") firstrow clear
twoway (connected coeff_nooutliers year, mcolor(black) msize(medium) msymbol(circle) lcolor(black) lwidth(medthick) lpattern(solid)) (line noconstant_nooutliers year, yaxis(2) lcolor(gs6) lwidth(medthick) lpattern(solid)), ytitle(Coefficient of Log Per Capita GDP) ytitle(, size(medium)) xtitle(.) xtitle(, size(zero) color(white)) xline(6, lwidth(medthick) lpattern(dash) lcolor(gs10)) xlabel(1(1)13) legend(order(1 "Coefficient of Log Per Capita GDP" 2 "Constant") rows(1) span) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
* We manually edit the graph using graph editor.
graph export figureA13.png, replace width(2620) height(1908)

***************
* FIGURE A.14 *
***************

use jv2015_country, clear
keep if urbrate != . & lpcgdp != .
reg nonag lpcgdp if year == 1980, robust
outreg2 lpcgdp using figureA14.xls, ci se bdec(2) adjr2 noni nolabel noaster bracket title(Effect, "") nonotes replace
foreach X of numlist 1990 2000 2010 {
reg nonag lpcgdp if year == `X', robust
outreg2 lpcgdp using figureA14.xls, ci se bdec(2) adjr2 noni nolabel noaster bracket title(Effect, "") nonotes append
}
* We add the coefficients to the excel file "robustness_summary.xls".

clear
import excel "robustness_summary.xls", sheet("constant") firstrow clear
twoway (connected coeff_induserv year, mcolor(black) msize(medium) msymbol(circle) lcolor(black) lwidth(medthick) lpattern(solid)) (line noconstant_induserv year, yaxis(2) lcolor(gs6) lwidth(medthick) lpattern(solid)), ytitle(Coefficient of Log Per Capita GDP) ytitle(, size(medium)) xtitle(.) xtitle(, size(zero) color(white)) xline(6, lwidth(medthick) lpattern(dash) lcolor(gs10)) xlabel(1(1)13) legend(order(1 "Coefficient of Log Per Capita GDP" 2 "Constant") rows(1) span) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
* We manually edit the graph using graph editor.
graph export figureA14.png, replace width(2620) height(1908)

***************
* FIGURE A.15 *
***************

use jv2015_country, clear
keep if year == 1700 | year == 1800 | year == 1850 | year == 1870 | year == 1913 | year == 1950 | year == 1960 | year == 1970 | year == 1980 | year == 1990 | year == 2000 | year == 2010
sort country year
gen lpcgdp_prev = lpcgdp[_n-1]
gen nonrecession = ((lpcgdp > lpcgdp_prev) & lpcgdp_prev != . & lpcgdp != .)
bysort year: tab nonrecession
keep if nonrecession == 1
reg urbrate lpcgdp if year == 1800, robust
outreg2 lpcgdp using graph2.xls, ci se bdec(2) adjr2 noni nolabel noaster bracket title(Effect, "") nonotes replace
foreach X of numlist 1850 1870 1913 1950 1960 1970 1980 1990 2000 2010 {
reg urbrate lpcgdp if year == `X', robust
outreg2 lpcgdp using graph2.xls, ci se bdec(2) adjr2 noni nolabel noaster bracket title(Effect, "") nonotes append
}
* We add the coefficients to the excel file "robustness_summary.xls".

clear
import excel "robustness_summary.xls", sheet("constant") firstrow clear
twoway (connected coeff_nonrecession year, mcolor(black) msize(medium) msymbol(circle) lcolor(black) lwidth(medthick) lpattern(solid)) (line noconstant_nonrecession year, yaxis(2) lcolor(gs6) lwidth(medthick) lpattern(solid)), ytitle(Coefficient of Log Per Capita GDP) ytitle(, size(medium)) xtitle(.) xtitle(, size(zero) color(white)) xline(6, lwidth(medthick) lpattern(dash) lcolor(gs10)) xlabel(1(1)13) legend(order(1 "Coefficient of Log Per Capita GDP" 2 "Constant") rows(1) span) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
* We manually edit the graph using graph editor.
graph export figureA15.png, replace width(2620) height(1908)

***************
* FIGURE A.16 *
***************

use jv2015_country, clear
keep if year >= 1950 & year <= 2010
sort country year
by country: gen lpcgdp_mean10 = (lpcgdp[_n-10] + lpcgdp[_n-9] + lpcgdp[_n-8] + lpcgdp[_n-7] + lpcgdp[_n-6] + lpcgdp[_n-5] + lpcgdp[_n-4] + lpcgdp[_n-3] + lpcgdp[_n-2] + lpcgdp[_n-1] + lpcgdp + lpcgdp[_n+1] + lpcgdp[_n+2] + lpcgdp[_n+3] + lpcgdp[_n+4] + lpcgdp[_n+5] + lpcgdp[_n+6] + lpcgdp[_n+7] + lpcgdp[_n+8] + lpcgdp[_n+9] + lpcgdp[_n+10]) / 21
reg urbrate lpcgdp_mean10 if year == 1960, robust 
outreg2 lpcgdp_mean10 using graph2.xls, ci se bdec(2) adjr2 noni nolabel noaster bracket title(Effect, "") nonotes replace
foreach X of numlist 1970 1980 1990 2000 {
reg urbrate lpcgdp_mean10 if year == `X', robust 
outreg2 lpcgdp_mean10 using graph2.xls, ci se bdec(2) adjr2 noni nolabel noaster bracket title(Effect, "") nonotes append
}
* We add the coefficients to the excel file "robustness_summary.xls".

clear
import excel "robustness_summary.xls", sheet("constant") firstrow clear
twoway (connected coeff_movav year, mcolor(black) msize(medium) msymbol(circle) lcolor(black) lwidth(medthick) lpattern(solid)) (line noconstant_movav year, yaxis(2) lcolor(gs6) lwidth(medthick) lpattern(solid)), ytitle(Coefficient of Log Per Capita GDP) ytitle(, size(medium)) xtitle(.) xtitle(, size(zero) color(white)) xline(6, lwidth(medthick) lpattern(dash) lcolor(gs10)) xlabel(1(1)13) legend(order(1 "Coefficient of Log Per Capita GDP" 2 "Constant") rows(1) span) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
* We manually edit the graph using graph editor.
graph export figureA16.png, replace width(2620) height(1908)

***************
* FIGURE A.17 *
***************

use jv2015_country, clear
keep if urbrate != . & lpcgdp != .
gen primcomp = lpc+lsc+lhc
reg urbrate primcomp if year == 1950, robust
outreg2 primcomp using figureA17.xls, ci se bdec(2) adjr2 noni nolabel noaster bracket title(Effect, "") nonotes replace
foreach X of numlist 1960 1970 1980 1990 2000 2010 {
reg urbrate primcomp if year == `X', robust
outreg2 primcomp using figureA17.xls, ci se bdec(2) adjr2 noni nolabel noaster bracket title(Effect, "") nonotes append
}
* We add the coefficients to the excel file "robustness_summary.xls".

clear
import excel "robustness_summary.xls", sheet("constant") firstrow clear
twoway (connected coeff_prim year, mcolor(black) msize(medium) msymbol(circle) lcolor(black) lwidth(medthick) lpattern(solid)) (line noconstant_prim year, yaxis(2) lcolor(gs6) lwidth(medthick) lpattern(solid)), ytitle(Coefficient of Log Per Capita GDP) ytitle(, size(medium)) xtitle(.) xtitle(, size(zero) color(white)) xline(6, lwidth(medthick) lpattern(dash) lcolor(gs10)) xlabel(1(1)13) legend(order(1 "Coefficient of Log Per Capita GDP" 2 "Constant") rows(1) span) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
* We manually edit the graph using graph editor.
graph export figureA17.png, replace width(2620) height(1908)

***************
* FIGURE A.18 *
***************

use jv2015_country, clear
keep if urbrate != . & lpcgdp != .
gen lyr_sch = log(yr_sch)
reg urbrate yr_sch if year == 1950, robust
outreg2 yr_sch using figureA18.xls, ci se bdec(2) adjr2 noni nolabel noaster bracket title(Effect, "") nonotes replace
foreach X of numlist 1960 1970 1980 1990 2000 2010 {
reg urbrate yr_sch if year == `X', robust
outreg2 yr_sch using figureA18.xls, ci se bdec(2) adjr2 noni nolabel noaster bracket title(Effect, "") nonotes append
}
* We add the coefficients to the excel file "robustness_summary.xls".

clear
import excel "robustness_summary.xls", sheet("constant") firstrow clear
twoway (connected coeff_yrsschool year, mcolor(black) msize(medium) msymbol(circle) lcolor(black) lwidth(medthick) lpattern(solid)) (line noconstant_yrsschool year, yaxis(2) lcolor(gs6) lwidth(medthick) lpattern(solid)), ytitle(Coefficient of Log Per Capita GDP) ytitle(, size(medium)) xtitle(.) xtitle(, size(zero) color(white)) xline(6, lwidth(medthick) lpattern(dash) lcolor(gs10)) xlabel(1(1)13) legend(order(1 "Coefficient of Log Per Capita GDP" 2 "Constant") rows(1) span) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
* We manually edit the graph using graph editor.
graph export figureA18.png, replace width(2620) height(1908)

***************
* FIGURE A.19 *
***************

use jv2015_country, clear
keep if urbrate != . & lpcgdp != .
reg urbrate lpcgdp if year == 1500 [pw = pop], robust
outreg2 lpcgdp using figureA19.xls, ci se bdec(2) adjr2 noni nolabel noaster bracket title(Effect, "") nonotes replace
foreach X of numlist 1700 1800 1850 1870 1913 1950 1960 1970 1980 1990 2000 2010 {
reg urbrate lpcgdp if year == `X' [pw = pop], robust
outreg2 lpcgdp using figureA19.xls, ci se bdec(2) adjr2 noni nolabel noaster bracket title(Effect, "") nonotes append
}
* We add the coefficients to the excel file "robustness_summary.xls".

clear
import excel "robustness_summary.xls", sheet("constant") firstrow clear
twoway (connected coeff_popweights year, mcolor(black) msize(medium) msymbol(circle) lcolor(black) lwidth(medthick) lpattern(solid)) (line noconstant_popweights year, yaxis(2) lcolor(gs6) lwidth(medthick) lpattern(solid)), ytitle(Coefficient of Log Per Capita GDP) ytitle(, size(medium)) xtitle(.) xtitle(, size(zero) color(white)) xline(6, lwidth(medthick) lpattern(dash) lcolor(gs10)) xlabel(1(1)13) legend(order(1 "Coefficient of Log Per Capita GDP" 2 "Constant") rows(1) span) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
* We manually edit the graph using graph editor.
graph export figureA19.png, replace width(2620) height(1908)

***************
* FIGURE A.20 *
***************

use jv2015_country, clear
keep if urbrate != . & lpcgdp != .
reg urbrate lpcgdp if year == 1500 [pw = area_sqkm], robust
outreg2 lpcgdp using figureA20.xls, ci se bdec(2) adjr2 noni nolabel noaster bracket title(Effect, "") nonotes replace
foreach X of numlist 1700 1800 1850 1870 1913 1950 1960 1970 1980 1990 2000 2010 {
reg urbrate lpcgdp if year == `X' [pw = area_sqkm], robust
outreg2 lpcgdp using figureA20.xls, ci se bdec(2) adjr2 noni nolabel noaster bracket title(Effect, "") nonotes append
}
* We add the coefficients to the excel file "robustness_summary.xls".

clear
import excel "robustness_summary.xls", sheet("constant") firstrow clear
twoway (connected coeff_areaweights year, mcolor(black) msize(medium) msymbol(circle) lcolor(black) lwidth(medthick) lpattern(solid)) (line noconstant_areaweights year, yaxis(2) lcolor(gs6) lwidth(medthick) lpattern(solid)), ytitle(Coefficient of Log Per Capita GDP) ytitle(, size(medium)) xtitle(.) xtitle(, size(zero) color(white)) xline(6, lwidth(medthick) lpattern(dash) lcolor(gs10)) xlabel(1(1)13) legend(order(1 "Coefficient of Log Per Capita GDP" 2 "Constant") rows(1) span) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
* We manually edit the graph using graph editor.
graph export figureA20.png, replace width(2620) height(1908)



